==> xlniuxdata-jinzuan-1.0.4-20141021.062936-1-sources.jar: com/xunlei/niux/data/jinzuan/vo/Price.java <==
package com.xunlei.niux.data.jinzuan.vo;

import com.ferret.common.dao.annotation.Table;


/**
 * 金钻单价
 * @author 李苏
 * @date 2014-02-27
 * @Descripter:
 */
@Table(tableName="jinzuan_price",pkFieldName="seqId",pkFieldAssign=false)
public class Price {

	private Long seqId;
	private String actNo;
	private String priceNo;
	private Double price;
	private Integer discount;
	private Double payPrice;
	private Boolean flag;
	private String inputBy;
	private String inputTime;
	private String editBy;
	private String editTime;
	private Integer timeType;
	private String remark;
	private String startTime;
	private String endTime;
	private String amounts;
	private Boolean amountFlag;
	
	
	
	public String getAmounts() {
		return amounts;
	}
	public void setAmounts(String amounts) {
		this.amounts = amounts;
	}
	public Boolean getAmountFlag() {
		return amountFlag;
	}
	public void setAmountFlag(Boolean amountFlag) {
		this.amountFlag = amountFlag;
	}
	public String getActNo() {
		return actNo;
	}
	public void setActNo(String actNo) {
		this.actNo = actNo;
	}
	public String getStartTime() {
		return startTime;
	}
	public void setStartTime(String startTime) {
		this.startTime = startTime;
	}
	public String getEndTime() {
		return endTime;
	}
	public void setEndTime(String endTime) {
		this.endTime = endTime;
	}		
	public String getRemark() {
		return remark;
	}
	public void setRemark(String remark) {
		this.remark = remark;
	}
    public Integer getTimeType() {
		return timeType;
	}
	public void setTimeType(Integer timeType) {
		this.timeType = timeType;
	}
	public Long getSeqId() {
		return seqId;
	}
	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}
	public String getPriceNo() {
		return priceNo;
	}
	public void setPriceNo(String priceNo) {
		this.priceNo = priceNo;
	}
	public Double getPrice() {
		return price;
	}
	public void setPrice(Double price) {
		this.price = price;
	}
	public Integer getDiscount() {
		return discount;
	}
	public void setDiscount(Integer discount) {
		this.discount = discount;
	}
	public Double getPayPrice() {
		return payPrice;
	}
	public void setPayPrice(Double payPrice) {
		this.payPrice = payPrice;
	}
	public Boolean getFlag() {
		return flag;
	}
	public void setFlag(Boolean flag) {
		this.flag = flag;
	}
	public String getInputBy() {
		return inputBy;
	}
	public void setInputBy(String inputBy) {
		this.inputBy = inputBy;
	}
	public String getInputTime() {
		return inputTime;
	}
	public void setInputTime(String inputTime) {
		this.inputTime = inputTime;
	}
	public String getEditBy() {
		return editBy;
	}
	public void setEditBy(String editBy) {
		this.editBy = editBy;
	}
	public String getEditTime() {
		return editTime;
	}
	public void setEditTime(String editTime) {
		this.editTime = editTime;
	}

}

==> xlniuxdata-jinzuan-1.0.5-20151102.060947-7-sources.jar: com/xunlei/niux/data/jinzuan/vo/Price.java <==
package com.xunlei.niux.data.jinzuan.vo;

import com.ferret.common.dao.annotation.Table;


/**
 * 金钻单价
 * @author 李苏
 * @date 2014-02-27
 * @Descripter:
 */
@Table(tableName="jinzuan_price",pkFieldName="seqId",pkFieldAssign=false)
public class Price {

	private Long seqId;
	private String actNo;
	private String priceNo;
	private Double price;
	private Integer discount;
	private Double payPrice;
	private Boolean flag;
	private String inputBy;
	private String inputTime;
	private String editBy;
	private String editTime;
	private Integer timeType;
	private String remark;
	private String startTime;
	private String endTime;
	private String amounts;
	private Boolean amountFlag;
	private Integer checkMemberStatus;
	
	
    
	public Integer getCheckMemberStatus() {
		return checkMemberStatus;
	}
	public void setCheckMemberStatus(Integer checkMemberStatus) {
		this.checkMemberStatus = checkMemberStatus;
	}
	public String getAmounts() {
		return amounts;
	}
	public void setAmounts(String amounts) {
		this.amounts = amounts;
	}
	public Boolean getAmountFlag() {
		return amountFlag;
	}
	public void setAmountFlag(Boolean amountFlag) {
		this.amountFlag = amountFlag;
	}
	public String getActNo() {
		return actNo;
	}
	public void setActNo(String actNo) {
		this.actNo = actNo;
	}
	public String getStartTime() {
		return startTime;
	}
	public void setStartTime(String startTime) {
		this.startTime = startTime;
	}
	public String getEndTime() {
		return endTime;
	}
	public void setEndTime(String endTime) {
		this.endTime = endTime;
	}		
	public String getRemark() {
		return remark;
	}
	public void setRemark(String remark) {
		this.remark = remark;
	}
    public Integer getTimeType() {
		return timeType;
	}
	public void setTimeType(Integer timeType) {
		this.timeType = timeType;
	}
	public Long getSeqId() {
		return seqId;
	}
	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}
	public String getPriceNo() {
		return priceNo;
	}
	public void setPriceNo(String priceNo) {
		this.priceNo = priceNo;
	}
	public Double getPrice() {
		return price;
	}
	public void setPrice(Double price) {
		this.price = price;
	}
	public Integer getDiscount() {
		return discount;
	}
	public void setDiscount(Integer discount) {
		this.discount = discount;
	}
	public Double getPayPrice() {
		return payPrice;
	}
	public void setPayPrice(Double payPrice) {
		this.payPrice = payPrice;
	}
	public Boolean getFlag() {
		return flag;
	}
	public void setFlag(Boolean flag) {
		this.flag = flag;
	}
	public String getInputBy() {
		return inputBy;
	}
	public void setInputBy(String inputBy) {
		this.inputBy = inputBy;
	}
	public String getInputTime() {
		return inputTime;
	}
	public void setInputTime(String inputTime) {
		this.inputTime = inputTime;
	}
	public String getEditBy() {
		return editBy;
	}
	public void setEditBy(String editBy) {
		this.editBy = editBy;
	}
	public String getEditTime() {
		return editTime;
	}
	public void setEditTime(String editTime) {
		this.editTime = editTime;
	}

}
